Invenio Framework v3 — Invenio 3.4.0a8 documentation

# Invenio Framework v3

Open Source framework for large-scale digital repositories.

Invenio Framework is like a Swiss Army knife of battle-tested, safe and secure modules providing you with all the features you need to build a trusted digital repository.

Built with Invenio Framework

Looking for a turn-key Research Data Management platform? Checkout InvenioRDM

Looking for a modern Integrated Library System? Checkout InvenioILS

- Getting started
  - What is Invenio Framework?
  - Setting up your system
  - Quickstart
  - Getting help
- Tutorials
  - Prerequisites
  - Invenio at a glance
  - Starting development with Invenio
  - Learning about data models
  - Invenio in production
  - Advanced topics
  - How-to’s
- Documentation
  - Requirements
  - Main concepts
  - Module Reference
- Community
  - Contributing
  - Security policy
  - Governance
  - Code of Conduct
  - License
  - History
- Releases
  - Maintenance Policy
  - Versions
  - Upgrading
  - Migrating to v3